abacusai.memory_options — AbacusAI documentation

# abacusai.memory_options

## Classes

`MemoryOptions` | The overall memory options for executing a job

## Module Contents

class abacusai.memory_options.MemoryOptions(client, cpu={}, gpu={})

  Bases: `abacusai.return_class.AbstractApiClass`

  The overall memory options for executing a job

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - cpu (CpuGpuMemorySpecs) – Contains information about the default CPU and list of CPU memory & size options

    - gpu (CpuGpuMemorySpecs) – Contains information about the default GPU and list of GPU memory & size options

  cpu
  gpu
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict